const endpointContainer = document.getElementById('endpoint-container');
const listContainer = document.getElementById('list-container');
const detailsContainer = document.getElementById('details-container');
const getEndpointsBtn = document.getElementById('get-endpoints-btn');

function getEndpoints() {
    fetch('https://swapi.co/api/')
        .then(function(response) {
            if (response.ok) {
                return response.json();
            }

            return Promise.reject(new Error('Promise not ok'));
        })
        .then(function(jsonResponse) {
            addBtns(jsonResponse);
        })
        .catch(function(error) {
            console.error(error);
        });
}

function addBtns(response) {
    const btnHtml = Object.keys(response).reduce(function(html, responseKey) {
        return (
            html +
            '<button data-url="' +
            response[responseKey] +
            '">' +
            responseKey +
            '</button>'
        );
    }, '');

    endpointContainer.innerHTML = btnHtml;
}

function listHtml(list) {
    return list.reduce(function(html, listItem) {
        return `
        ${html}
        <article class="list-item">
            <p>${listItem.name ? listItem.name : listItem.title}</p>
            <button data-url="${listItem.url}">Show details</button>
        </article>
        `;
    }, '');
}

function requestList(event) {
    if (event.target.matches('button')) {
        let btn = event.target;
        btn.disabled = true;
        let btnText = btn.innerHTML;
        btn.innerHTML = 'loading...';

        fetch(event.target.dataset.url)
            .then(function(response) {
                if (response.ok) {
                    return response.json();
                }

                return Promise.reject(new Error('Request failed'));
            })
            .then(function(jsonResponse) {
                console.log(jsonResponse);
                btn.innerHTML = btnText;
                listContainer.innerHTML = listHtml(jsonResponse.results);
                btn.disabled = false;
            })
            .catch(function(error) {
                console.error(error);
                btn.innerHTML = 'Dikke fail...';
                btn.disabled = false;
            });
    }
}

function listDetails(details) {
    return Object.keys(details).reduce(function(html, detailKey) {
        return `
        ${html}
        <p>
            <strong>${detailKey}:</strong>
            ${details[detailKey]}
        </p>
        `;
    }, '');
}

function requestDetails(event) {
    if (event.target.matches('button')) {
        let btn = event.target;
        btn.disabled = true;
        let btnText = btn.innerHTML;
        btn.innerHTML = 'loading...';

        fetch(event.target.dataset.url)
            .then(function(response) {
                if (response.ok) {
                    return response.json();
                }

                return Promise.reject(new Error('Request failed'));
            })
            .then(function(jsonResponse) {
                console.log(jsonResponse);
                btn.innerHTML = btnText;
                detailsContainer.innerHTML = listDetails(jsonResponse);
                btn.disabled = false;
            })
            .catch(function(error) {
                console.error(error);
                btn.innerHTML = 'Dikke fail...';
                btn.disabled = false;
            });
    }
}

getEndpointsBtn.addEventListener('click', getEndpoints);
endpointContainer.addEventListener('click', requestList);
listContainer.addEventListener('click', requestDetails);
